# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/apollo/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.apollo import submission_pb2 as eolymp_dot_apollo_dot_submission__pb2
from eolymp.apollo import score_pb2 as eolymp_dot_apollo_dot_score__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/apollo/events.proto',
  package='eolymp.apollo',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/apollo;apollo',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/apollo/events.proto\x12\reolymp.apollo\x1a\x1e\x65olymp/apollo/submission.proto\x1a\x19\x65olymp/apollo/score.proto\"Y\n\x18SubmissionCompletedEvent\x12-\n\nsubmission\x18\x01 \x01(\x0b\x32\x19.eolymp.apollo.Submission\x12\x0e\n\x06update\x18\x02 \x01(\x08\"8\n\x11ScoreUpdatedEvent\x12#\n\x05score\x18\x01 \x01(\x0b\x32\x14.eolymp.apollo.Score\"5\n\x0eStarAddedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"7\n\x10StarRemovedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\tB5Z3github.com/eolymp/contracts/go/eolymp/apollo;apollob\x06proto3'
  ,
  dependencies=[eolymp_dot_apollo_dot_submission__pb2.DESCRIPTOR,eolymp_dot_apollo_dot_score__pb2.DESCRIPTOR,])




_SUBMISSIONCOMPLETEDEVENT = _descriptor.Descriptor(
  name='SubmissionCompletedEvent',
  full_name='eolymp.apollo.SubmissionCompletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='eolymp.apollo.SubmissionCompletedEvent.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='eolymp.apollo.SubmissionCompletedEvent.update', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=193,
)


_SCOREUPDATEDEVENT = _descriptor.Descriptor(
  name='ScoreUpdatedEvent',
  full_name='eolymp.apollo.ScoreUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.apollo.ScoreUpdatedEvent.score', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=251,
)


_STARADDEDEVENT = _descriptor.Descriptor(
  name='StarAddedEvent',
  full_name='eolymp.apollo.StarAddedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.StarAddedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.apollo.StarAddedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=306,
)


_STARREMOVEDEVENT = _descriptor.Descriptor(
  name='StarRemovedEvent',
  full_name='eolymp.apollo.StarRemovedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.StarRemovedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.apollo.StarRemovedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=363,
)

_SUBMISSIONCOMPLETEDEVENT.fields_by_name['submission'].message_type = eolymp_dot_apollo_dot_submission__pb2._SUBMISSION
_SCOREUPDATEDEVENT.fields_by_name['score'].message_type = eolymp_dot_apollo_dot_score__pb2._SCORE
DESCRIPTOR.message_types_by_name['SubmissionCompletedEvent'] = _SUBMISSIONCOMPLETEDEVENT
DESCRIPTOR.message_types_by_name['ScoreUpdatedEvent'] = _SCOREUPDATEDEVENT
DESCRIPTOR.message_types_by_name['StarAddedEvent'] = _STARADDEDEVENT
DESCRIPTOR.message_types_by_name['StarRemovedEvent'] = _STARREMOVEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubmissionCompletedEvent = _reflection.GeneratedProtocolMessageType('SubmissionCompletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _SUBMISSIONCOMPLETEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.SubmissionCompletedEvent)
  })
_sym_db.RegisterMessage(SubmissionCompletedEvent)

ScoreUpdatedEvent = _reflection.GeneratedProtocolMessageType('ScoreUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _SCOREUPDATEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.ScoreUpdatedEvent)
  })
_sym_db.RegisterMessage(ScoreUpdatedEvent)

StarAddedEvent = _reflection.GeneratedProtocolMessageType('StarAddedEvent', (_message.Message,), {
  'DESCRIPTOR' : _STARADDEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.StarAddedEvent)
  })
_sym_db.RegisterMessage(StarAddedEvent)

StarRemovedEvent = _reflection.GeneratedProtocolMessageType('StarRemovedEvent', (_message.Message,), {
  'DESCRIPTOR' : _STARREMOVEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.StarRemovedEvent)
  })
_sym_db.RegisterMessage(StarRemovedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/submission.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/submission.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x65olymp/judge/submission.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8b\x0c\n\nSubmission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12\x12\n\nproblem_id\x18\x03 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x04 \x01(\t\x12\x30\n\x0csubmitted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04lang\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x11\n\tsignature\x18\x0c \x01(\t\x12/\n\x06status\x18\x14 \x01(\x0e\x32\x1f.eolymp.judge.Submission.Status\x12\r\n\x05\x65rror\x18\x15 \x01(\t\x12\x0c\n\x04\x63ost\x18\x1e \x01(\x02\x12\r\n\x05score\x18\x1f \x01(\x02\x12\x12\n\npercentage\x18  \x01(\x02\x12.\n\x06groups\x18\x32 \x03(\x0b\x32\x1e.eolymp.judge.Submission.Group\x1a\x95\x03\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x03 \x01(\r\x12\x14\n\x0cmemory_usage\x18\x04 \x01(\x04\x12\r\n\x05index\x18\n \x01(\r\x12\x0f\n\x07test_id\x18\x0b \x01(\t\x12\x0c\n\x04\x63ost\x18\x0c \x01(\x02\x12\r\n\x05score\x18\r \x01(\x02\x12\x33\n\x06status\x18\x14 \x01(\x0e\x32#.eolymp.judge.Submission.Run.Status\"\xc8\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x10\n\x0cWRONG_ANSWER\x10\x06\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x07\x12\x11\n\rRUNTIME_ERROR\x10\x08\x12\x16\n\x12VERIFICATION_ERROR\x10\t\x12\x0b\n\x07SKIPPED\x10\n\x12\x0b\n\x07\x42LOCKED\x10\x0b\x1a\xb3\x05\n\x05Group\x12\r\n\x05index\x18\x01 \x01(\r\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x35\n\x06status\x18\n \x01(\x0e\x32%.eolymp.judge.Submission.Group.Status\x12\x14\n\x0c\x64\x65pendencies\x18\x0b \x03(\r\x12\x0c\n\x04\x63ost\x18\x14 \x01(\x02\x12\r\n\x05score\x18\x15 \x01(\x02\x12@\n\x0cscoring_mode\x18\x16 \x01(\x0e\x32*.eolymp.judge.Submission.Group.ScoringMode\x12\x46\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18\x1e \x01(\x0e\x32-.eolymp.judge.Submission.Group.FeedbackPolicy\x12\x17\n\x0fwall_time_usage\x18) \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18* \x01(\r\x12\x14\n\x0cmemory_usage\x18. \x01(\x04\x12*\n\x04runs\x18\x64 \x03(\x0b\x32\x1c.eolymp.judge.Submission.Run\"\xc9\x01\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x42LOCKED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\x12\x11\n\rCPU_EXHAUSTED\x10\x06\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x07\x12\x10\n\x0cWRONG_ANSWER\x10\x08\x12\x11\n\rRUNTIME_ERROR\x10\t\x12\x16\n\x12VERIFICATION_ERROR\x10\n\x12\x0b\n\x07SKIPPED\x10\x0b\"*\n\x0bScoringMode\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x45\x41\x43H\x10\x01\x12\x07\n\x03\x41LL\x10\x02\"(\n\x0e\x46\x65\x65\x64\x62\x61\x63kPolicy\x12\x0c\n\x08\x43OMPLETE\x10\x00\x12\x08\n\x04ICPC\x10\x01\"_\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07TESTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0b\n\x07\x46\x41ILURE\x10\x06\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SUBMISSION_RUN_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Submission.Run.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXECUTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPU_EXHAUSTED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEMORY_OVERFLOW', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WRONG_ANSWER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNTIME_ERROR', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERIFICATION_ERROR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCKED', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=637,
  serialized_end=837,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_RUN_STATUS)

_SUBMISSION_GROUP_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Submission.Group.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCKED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPU_EXHAUSTED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEMORY_OVERFLOW', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WRONG_ANSWER', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNTIME_ERROR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERIFICATION_ERROR', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1244,
  serialized_end=1445,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_GROUP_STATUS)

_SUBMISSION_GROUP_SCORINGMODE = _descriptor.EnumDescriptor(
  name='ScoringMode',
  full_name='eolymp.judge.Submission.Group.ScoringMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EACH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1447,
  serialized_end=1489,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_GROUP_SCORINGMODE)

_SUBMISSION_GROUP_FEEDBACKPOLICY = _descriptor.EnumDescriptor(
  name='FeedbackPolicy',
  full_name='eolymp.judge.Submission.Group.FeedbackPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICPC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1491,
  serialized_end=1531,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_GROUP_FEEDBACKPOLICY)

_SUBMISSION_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Submission.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1533,
  serialized_end=1628,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_STATUS)


_SUBMISSION_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='eolymp.judge.Submission.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Submission.Run.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wall_time_usage', full_name='eolymp.judge.Submission.Run.wall_time_usage', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_time_usage', full_name='eolymp.judge.Submission.Run.cpu_time_usage', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_usage', full_name='eolymp.judge.Submission.Run.memory_usage', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.judge.Submission.Run.index', index=4,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_id', full_name='eolymp.judge.Submission.Run.test_id', index=5,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='eolymp.judge.Submission.Run.cost', index=6,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Submission.Run.score', index=7,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Submission.Run.status', index=8,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SUBMISSION_RUN_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=837,
)

_SUBMISSION_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='eolymp.judge.Submission.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.judge.Submission.Group.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testset_id', full_name='eolymp.judge.Submission.Group.testset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Submission.Group.status', index=2,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dependencies', full_name='eolymp.judge.Submission.Group.dependencies', index=3,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='eolymp.judge.Submission.Group.cost', index=4,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Submission.Group.score', index=5,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoring_mode', full_name='eolymp.judge.Submission.Group.scoring_mode', index=6,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback_policy', full_name='eolymp.judge.Submission.Group.feedback_policy', index=7,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wall_time_usage', full_name='eolymp.judge.Submission.Group.wall_time_usage', index=8,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_time_usage', full_name='eolymp.judge.Submission.Group.cpu_time_usage', index=9,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_usage', full_name='eolymp.judge.Submission.Group.memory_usage', index=10,
      number=46, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runs', full_name='eolymp.judge.Submission.Group.runs', index=11,
      number=100, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SUBMISSION_GROUP_STATUS,
    _SUBMISSION_GROUP_SCORINGMODE,
    _SUBMISSION_GROUP_FEEDBACKPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=1531,
)

_SUBMISSION = _descriptor.Descriptor(
  name='Submission',
  full_name='eolymp.judge.Submission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Submission.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.Submission.contest_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.Submission.problem_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.Submission.participant_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submitted_at', full_name='eolymp.judge.Submission.submitted_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.judge.Submission.lang', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.judge.Submission.source', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='eolymp.judge.Submission.signature', index=7,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Submission.status', index=8,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='eolymp.judge.Submission.error', index=9,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='eolymp.judge.Submission.cost', index=10,
      number=30, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Submission.score', index=11,
      number=31, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='eolymp.judge.Submission.percentage', index=12,
      number=32, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='eolymp.judge.Submission.groups', index=13,
      number=50, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SUBMISSION_RUN, _SUBMISSION_GROUP, ],
  enum_types=[
    _SUBMISSION_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=1628,
)

_SUBMISSION_RUN.fields_by_name['status'].enum_type = _SUBMISSION_RUN_STATUS
_SUBMISSION_RUN.containing_type = _SUBMISSION
_SUBMISSION_RUN_STATUS.containing_type = _SUBMISSION_RUN
_SUBMISSION_GROUP.fields_by_name['status'].enum_type = _SUBMISSION_GROUP_STATUS
_SUBMISSION_GROUP.fields_by_name['scoring_mode'].enum_type = _SUBMISSION_GROUP_SCORINGMODE
_SUBMISSION_GROUP.fields_by_name['feedback_policy'].enum_type = _SUBMISSION_GROUP_FEEDBACKPOLICY
_SUBMISSION_GROUP.fields_by_name['runs'].message_type = _SUBMISSION_RUN
_SUBMISSION_GROUP.containing_type = _SUBMISSION
_SUBMISSION_GROUP_STATUS.containing_type = _SUBMISSION_GROUP
_SUBMISSION_GROUP_SCORINGMODE.containing_type = _SUBMISSION_GROUP
_SUBMISSION_GROUP_FEEDBACKPOLICY.containing_type = _SUBMISSION_GROUP
_SUBMISSION.fields_by_name['submitted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SUBMISSION.fields_by_name['status'].enum_type = _SUBMISSION_STATUS
_SUBMISSION.fields_by_name['groups'].message_type = _SUBMISSION_GROUP
_SUBMISSION_STATUS.containing_type = _SUBMISSION
DESCRIPTOR.message_types_by_name['Submission'] = _SUBMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Submission = _reflection.GeneratedProtocolMessageType('Submission', (_message.Message,), {

  'Run' : _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
    'DESCRIPTOR' : _SUBMISSION_RUN,
    '__module__' : 'eolymp.judge.submission_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Submission.Run)
    })
  ,

  'Group' : _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
    'DESCRIPTOR' : _SUBMISSION_GROUP,
    '__module__' : 'eolymp.judge.submission_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Submission.Group)
    })
  ,
  'DESCRIPTOR' : _SUBMISSION,
  '__module__' : 'eolymp.judge.submission_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Submission)
  })
_sym_db.RegisterMessage(Submission)
_sym_db.RegisterMessage(Submission.Run)
_sym_db.RegisterMessage(Submission.Group)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class JudgeClient:
    def __init__(self, transport):
        self.transport = transport

    def CreateContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/CreateContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.CreateContestOutput"),
            **kwargs,
        )

    def DeleteContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DeleteContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DeleteContestOutput"),
            **kwargs,
        )

    def UpdateContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/UpdateContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.UpdateContestOutput"),
            **kwargs,
        )

    def LookupContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/LookupContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.LookupContestOutput"),
            **kwargs,
        )

    def DescribeContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeContestOutput"),
            **kwargs,
        )

    def ListContests(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ListContests",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ListContestsOutput"),
            **kwargs,
        )

    def OpenContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/OpenContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.OpenContestOutput"),
            **kwargs,
        )

    def CloseContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/CloseContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.CloseContestOutput"),
            **kwargs,
        )

    def ConfigureRegistrationForm(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ConfigureRegistrationForm",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ConfigureRegistrationFormOutput"),
            **kwargs,
        )

    def DescribeRegistrationForm(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeRegistrationForm",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeRegistrationFormOutput"),
            **kwargs,
        )

    def ConfigureRuntime(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ConfigureRuntime",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ConfigureRuntimeOutput"),
            **kwargs,
        )

    def DescribeRuntime(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeRuntime",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeRuntimeOutput"),
            **kwargs,
        )

    def SubmitRegistration(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/SubmitRegistration",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.SubmitRegistrationOutput"),
            **kwargs,
        )

    def DescribeRegistration(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeRegistration",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeRegistrationOutput"),
            **kwargs,
        )

    def ImportProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ImportProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ImportProblemOutput"),
            **kwargs,
        )

    def SyncProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/SyncProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.SyncProblemOutput"),
            **kwargs,
        )

    def UpdateProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/UpdateProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.UpdateProblemOutput"),
            **kwargs,
        )

    def ListProblems(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ListProblems",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ListProblemsOutput"),
            **kwargs,
        )

    def DescribeProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeProblemOutput"),
            **kwargs,
        )

    def ListStatements(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ListStatements",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ListStatementsOutput"),
            **kwargs,
        )

    def ListExamples(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ListExamples",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ListExamplesOutput"),
            **kwargs,
        )

    def DeleteProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DeleteProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DeleteProblemOutput"),
            **kwargs,
        )

    def RetestProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/RetestProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.RetestProblemOutput"),
            **kwargs,
        )

    def AddParticipant(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/AddParticipant",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.AddParticipantOutput"),
            **kwargs,
        )

    def EnableParticipant(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/EnableParticipant",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.EnableParticipantOutput"),
            **kwargs,
        )

    def DisableParticipant(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DisableParticipant",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DisableParticipantOutput"),
            **kwargs,
        )

    def VerifyPasscode(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/VerifyPasscode",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.VerifyPasscodeOutput"),
            **kwargs,
        )

    def EnterPasscode(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/EnterPasscode",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.EnterPasscodeOutput"),
            **kwargs,
        )

    def ResetPasscode(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ResetPasscode",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ResetPasscodeOutput"),
            **kwargs,
        )

    def RemovePasscode(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/RemovePasscode",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.RemovePasscodeOutput"),
            **kwargs,
        )

    def RemoveParticipant(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/RemoveParticipant",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.RemoveParticipantOutput"),
            **kwargs,
        )

    def ListParticipants(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ListParticipants",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ListParticipantsOutput"),
            **kwargs,
        )

    def DescribeParticipant(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeParticipant",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeParticipantOutput"),
            **kwargs,
        )

    def IntrospectParticipant(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/IntrospectParticipant",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.IntrospectParticipantOutput"),
            **kwargs,
        )

    def JoinContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/JoinContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.JoinContestOutput"),
            **kwargs,
        )

    def StartContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/StartContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.StartContestOutput"),
            **kwargs,
        )

    def CreateSubmission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/CreateSubmission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.CreateSubmissionOutput"),
            **kwargs,
        )

    def ListSubmissions(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ListSubmissions",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ListSubmissionsOutput"),
            **kwargs,
        )

    def DescribeSubmission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeSubmission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeSubmissionOutput"),
            **kwargs,
        )

    def RetestSubmission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/RetestSubmission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.RetestSubmissionOutput"),
            **kwargs,
        )

    def CreateTicket(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/CreateTicket",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.CreateTicketOutput"),
            **kwargs,
        )

    def CloseTicket(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/CloseTicket",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.CloseTicketOutput"),
            **kwargs,
        )

    def OpenTicket(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/OpenTicket",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.OpenTicketOutput"),
            **kwargs,
        )

    def ReadTicket(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ReadTicket",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ReadTicketOutput"),
            **kwargs,
        )

    def DeleteTicket(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DeleteTicket",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DeleteTicketOutput"),
            **kwargs,
        )

    def DescribeTicket(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeTicket",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeTicketOutput"),
            **kwargs,
        )

    def ListTickets(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ListTickets",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ListTicketsOutput"),
            **kwargs,
        )

    def ReplyTicket(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ReplyTicket",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ReplyTicketOutput"),
            **kwargs,
        )

    def ListReplies(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ListReplies",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ListRepliesOutput"),
            **kwargs,
        )

    def DeleteReply(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DeleteReply",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DeleteReplyOutput"),
            **kwargs,
        )

    def UpdateReply(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/UpdateReply",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.UpdateReplyOutput"),
            **kwargs,
        )

    def CreateAnnouncement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/CreateAnnouncement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.CreateAnnouncementOutput"),
            **kwargs,
        )

    def UpdateAnnouncement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/UpdateAnnouncement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.UpdateAnnouncementOutput"),
            **kwargs,
        )

    def DeleteAnnouncement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DeleteAnnouncement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DeleteAnnouncementOutput"),
            **kwargs,
        )

    def ReadAnnouncement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ReadAnnouncement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ReadAnnouncementOutput"),
            **kwargs,
        )

    def DescribeAnnouncement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeAnnouncement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeAnnouncementOutput"),
            **kwargs,
        )

    def DescribeAnnouncementStatus(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeAnnouncementStatus",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeAnnouncementStatusOutput"),
            **kwargs,
        )

    def ListAnnouncements(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/ListAnnouncements",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.ListAnnouncementsOutput"),
            **kwargs,
        )

    def DescribeCodeTemplate(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.judge.Judge/DescribeCodeTemplate",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.judge.DescribeCodeTemplateOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/statement.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/statement.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x65olymp/atlas/statement.proto\x12\x0c\x65olymp.atlas\"\xe0\x01\n\tStatement\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12.\n\x06\x66ormat\x18\x06 \x01(\x0e\x32\x1e.eolymp.atlas.Statement.Format\x12\x0e\n\x06\x61uthor\x18\x65 \x01(\t\x12\x0e\n\x06source\x18\x66 \x01(\t\"3\n\x06\x46ormat\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03TEX\x10\x01\x12\x0c\n\x08MARKDOWN\x10\x02\x12\x08\n\x04HTML\x10\x03\x42\x33Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
)



_STATEMENT_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='eolymp.atlas.Statement.Format',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARKDOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTML', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=220,
  serialized_end=271,
)
_sym_db.RegisterEnumDescriptor(_STATEMENT_FORMAT)


_STATEMENT = _descriptor.Descriptor(
  name='Statement',
  full_name='eolymp.atlas.Statement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.atlas.Statement.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.Statement.problem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.atlas.Statement.locale', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='eolymp.atlas.Statement.title', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='eolymp.atlas.Statement.content', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='eolymp.atlas.Statement.format', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='eolymp.atlas.Statement.author', index=6,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.atlas.Statement.source', index=7,
      number=102, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATEMENT_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=271,
)

_STATEMENT.fields_by_name['format'].enum_type = _STATEMENT_FORMAT
_STATEMENT_FORMAT.containing_type = _STATEMENT
DESCRIPTOR.message_types_by_name['Statement'] = _STATEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Statement = _reflection.GeneratedProtocolMessageType('Statement', (_message.Message,), {
  'DESCRIPTOR' : _STATEMENT,
  '__module__' : 'eolymp.atlas.statement_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.Statement)
  })
_sym_db.RegisterMessage(Statement)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/wellknown/expression.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/wellknown/expression.proto',
  package='eolymp.wellknown',
  syntax='proto3',
  serialized_options=b'Z9github.com/eolymp/contracts/go/eolymp/wellknown;wellknown',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!eolymp/wellknown/expression.proto\x12\x10\x65olymp.wellknown\x1a\x1fgoogle/protobuf/timestamp.proto\"z\n\x0c\x45xpressionID\x12/\n\x02is\x18\x01 \x01(\x0e\x32#.eolymp.wellknown.ExpressionID.Type\x12\r\n\x05value\x18\x02 \x01(\t\"*\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\"\xca\x01\n\rExpressionInt\x12\x30\n\x02is\x18\x01 \x01(\x0e\x32$.eolymp.wellknown.ExpressionInt.Type\x12\r\n\x05value\x18\x02 \x01(\x05\"x\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x16\n\x12GREATER_THAN_EQUAL\x10\x04\x12\r\n\tLESS_THAN\x10\x05\x12\x13\n\x0fLESS_THAN_EQUAL\x10\x06\"\xce\x01\n\x0f\x45xpressionFloat\x12\x32\n\x02is\x18\x01 \x01(\x0e\x32&.eolymp.wellknown.ExpressionFloat.Type\x12\r\n\x05value\x18\x02 \x01(\x02\"x\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x16\n\x12GREATER_THAN_EQUAL\x10\x04\x12\r\n\tLESS_THAN\x10\x05\x12\x13\n\x0fLESS_THAN_EQUAL\x10\x06\"\x92\x01\n\x10\x45xpressionString\x12\x33\n\x02is\x18\x01 \x01(\x0e\x32\'.eolymp.wellknown.ExpressionString.Type\x12\r\n\x05value\x18\x02 \x01(\t\":\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x0e\n\nCONTAINING\x10\x03\"~\n\x0e\x45xpressionEnum\x12\x31\n\x02is\x18\x01 \x01(\x0e\x32%.eolymp.wellknown.ExpressionEnum.Type\x12\r\n\x05value\x18\x02 \x01(\t\"*\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\"o\n\x0e\x45xpressionBool\x12\x31\n\x02is\x18\x01 \x01(\x0e\x32%.eolymp.wellknown.ExpressionBool.Type\x12\r\n\x05value\x18\x02 \x01(\x08\"\x1b\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\"\xf2\x01\n\x13\x45xpressionTimestamp\x12\x36\n\x02is\x18\x01 \x01(\x0e\x32*.eolymp.wellknown.ExpressionTimestamp.Type\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"x\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tNOT_EQUAL\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x16\n\x12GREATER_THAN_EQUAL\x10\x04\x12\r\n\tLESS_THAN\x10\x05\x12\x13\n\x0fLESS_THAN_EQUAL\x10\x06\x42;Z9github.com/eolymp/contracts/go/eolymp/wellknown;wellknownb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_EXPRESSIONID_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionID.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=210,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONID_TYPE)

_EXPRESSIONINT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionInt.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_EQUAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_EQUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=295,
  serialized_end=415,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONINT_TYPE)

_EXPRESSIONFLOAT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionFloat.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_EQUAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_EQUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=295,
  serialized_end=415,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONFLOAT_TYPE)

_EXPRESSIONSTRING_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionString.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=715,
  serialized_end=773,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONSTRING_TYPE)

_EXPRESSIONENUM_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionEnum.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=210,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONENUM_TYPE)

_EXPRESSIONBOOL_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionBool.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=195,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONBOOL_TYPE)

_EXPRESSIONTIMESTAMP_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.wellknown.ExpressionTimestamp.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_EQUAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_EQUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=295,
  serialized_end=415,
)
_sym_db.RegisterEnumDescriptor(_EXPRESSIONTIMESTAMP_TYPE)


_EXPRESSIONID = _descriptor.Descriptor(
  name='ExpressionID',
  full_name='eolymp.wellknown.ExpressionID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionID.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionID.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONID_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=210,
)


_EXPRESSIONINT = _descriptor.Descriptor(
  name='ExpressionInt',
  full_name='eolymp.wellknown.ExpressionInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionInt.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionInt.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONINT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=415,
)


_EXPRESSIONFLOAT = _descriptor.Descriptor(
  name='ExpressionFloat',
  full_name='eolymp.wellknown.ExpressionFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionFloat.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionFloat.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONFLOAT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=624,
)


_EXPRESSIONSTRING = _descriptor.Descriptor(
  name='ExpressionString',
  full_name='eolymp.wellknown.ExpressionString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionString.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionString.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONSTRING_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=773,
)


_EXPRESSIONENUM = _descriptor.Descriptor(
  name='ExpressionEnum',
  full_name='eolymp.wellknown.ExpressionEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionEnum.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionEnum.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONENUM_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=901,
)


_EXPRESSIONBOOL = _descriptor.Descriptor(
  name='ExpressionBool',
  full_name='eolymp.wellknown.ExpressionBool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionBool.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionBool.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONBOOL_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=1014,
)


_EXPRESSIONTIMESTAMP = _descriptor.Descriptor(
  name='ExpressionTimestamp',
  full_name='eolymp.wellknown.ExpressionTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is', full_name='eolymp.wellknown.ExpressionTimestamp.is', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ExpressionTimestamp.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPRESSIONTIMESTAMP_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1259,
)

_EXPRESSIONID.fields_by_name['is'].enum_type = _EXPRESSIONID_TYPE
_EXPRESSIONID_TYPE.containing_type = _EXPRESSIONID
_EXPRESSIONINT.fields_by_name['is'].enum_type = _EXPRESSIONINT_TYPE
_EXPRESSIONINT_TYPE.containing_type = _EXPRESSIONINT
_EXPRESSIONFLOAT.fields_by_name['is'].enum_type = _EXPRESSIONFLOAT_TYPE
_EXPRESSIONFLOAT_TYPE.containing_type = _EXPRESSIONFLOAT
_EXPRESSIONSTRING.fields_by_name['is'].enum_type = _EXPRESSIONSTRING_TYPE
_EXPRESSIONSTRING_TYPE.containing_type = _EXPRESSIONSTRING
_EXPRESSIONENUM.fields_by_name['is'].enum_type = _EXPRESSIONENUM_TYPE
_EXPRESSIONENUM_TYPE.containing_type = _EXPRESSIONENUM
_EXPRESSIONBOOL.fields_by_name['is'].enum_type = _EXPRESSIONBOOL_TYPE
_EXPRESSIONBOOL_TYPE.containing_type = _EXPRESSIONBOOL
_EXPRESSIONTIMESTAMP.fields_by_name['is'].enum_type = _EXPRESSIONTIMESTAMP_TYPE
_EXPRESSIONTIMESTAMP.fields_by_name['value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPRESSIONTIMESTAMP_TYPE.containing_type = _EXPRESSIONTIMESTAMP
DESCRIPTOR.message_types_by_name['ExpressionID'] = _EXPRESSIONID
DESCRIPTOR.message_types_by_name['ExpressionInt'] = _EXPRESSIONINT
DESCRIPTOR.message_types_by_name['ExpressionFloat'] = _EXPRESSIONFLOAT
DESCRIPTOR.message_types_by_name['ExpressionString'] = _EXPRESSIONSTRING
DESCRIPTOR.message_types_by_name['ExpressionEnum'] = _EXPRESSIONENUM
DESCRIPTOR.message_types_by_name['ExpressionBool'] = _EXPRESSIONBOOL
DESCRIPTOR.message_types_by_name['ExpressionTimestamp'] = _EXPRESSIONTIMESTAMP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExpressionID = _reflection.GeneratedProtocolMessageType('ExpressionID', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONID,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionID)
  })
_sym_db.RegisterMessage(ExpressionID)

ExpressionInt = _reflection.GeneratedProtocolMessageType('ExpressionInt', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONINT,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionInt)
  })
_sym_db.RegisterMessage(ExpressionInt)

ExpressionFloat = _reflection.GeneratedProtocolMessageType('ExpressionFloat', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONFLOAT,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionFloat)
  })
_sym_db.RegisterMessage(ExpressionFloat)

ExpressionString = _reflection.GeneratedProtocolMessageType('ExpressionString', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONSTRING,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionString)
  })
_sym_db.RegisterMessage(ExpressionString)

ExpressionEnum = _reflection.GeneratedProtocolMessageType('ExpressionEnum', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONENUM,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionEnum)
  })
_sym_db.RegisterMessage(ExpressionEnum)

ExpressionBool = _reflection.GeneratedProtocolMessageType('ExpressionBool', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONBOOL,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionBool)
  })
_sym_db.RegisterMessage(ExpressionBool)

ExpressionTimestamp = _reflection.GeneratedProtocolMessageType('ExpressionTimestamp', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONTIMESTAMP,
  '__module__' : 'eolymp.wellknown.expression_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ExpressionTimestamp)
  })
_sym_db.RegisterMessage(ExpressionTimestamp)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class KeeperClient:
    def __init__(self, transport):
        self.transport = transport

    def CreateObject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.keeper.Keeper/CreateObject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.keeper.CreateObjectOutput"),
            **kwargs,
        )

    def DescribeObject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.keeper.Keeper/DescribeObject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.keeper.DescribeObjectOutput"),
            **kwargs,
        )

    def DownloadObject(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.keeper.Keeper/DownloadObject",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.keeper.DownloadObjectOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/apollo/submission.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/apollo/submission.proto',
  package='eolymp.apollo',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/apollo;apollo',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/apollo/submission.proto\x12\reolymp.apollo\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdf\x05\n\nSubmission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x30\n\x0csubmitted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04lang\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x30\n\x06status\x18\x14 \x01(\x0e\x32 .eolymp.apollo.Submission.Status\x12\r\n\x05\x65rror\x18\x15 \x01(\t\x12\r\n\x05score\x18\x1e \x01(\x02\x12+\n\x04runs\x18\x32 \x03(\x0b\x32\x1d.eolymp.apollo.Submission.Run\x1a\xf1\x02\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\x05\x12\x16\n\x0e\x63pu_time_usage\x18\x03 \x01(\x05\x12\x14\n\x0cmemory_usage\x18\x04 \x01(\x05\x12\x12\n\ntest_index\x18\n \x01(\x05\x12\x0f\n\x07test_id\x18\x0b \x01(\t\x12\x34\n\x06status\x18\x14 \x01(\x0e\x32$.eolymp.apollo.Submission.Run.Status\"\xbb\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x10\n\x0cWRONG_ANSWER\x10\x06\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x07\x12\x11\n\rRUNTIME_ERROR\x10\x08\x12\x16\n\x12VERIFICATION_ERROR\x10\t\x12\x0b\n\x07SKIPPED\x10\n\"_\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07TESTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0b\n\x07\x46\x41ILURE\x10\x06\x42\x35Z3github.com/eolymp/contracts/go/eolymp/apollo;apollob\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SUBMISSION_RUN_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.apollo.Submission.Run.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXECUTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPU_EXHAUSTED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEMORY_OVERFLOW', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WRONG_ANSWER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNTIME_ERROR', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERIFICATION_ERROR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=534,
  serialized_end=721,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_RUN_STATUS)

_SUBMISSION_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.apollo.Submission.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=723,
  serialized_end=818,
)
_sym_db.RegisterEnumDescriptor(_SUBMISSION_STATUS)


_SUBMISSION_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='eolymp.apollo.Submission.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.apollo.Submission.Run.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wall_time_usage', full_name='eolymp.apollo.Submission.Run.wall_time_usage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_time_usage', full_name='eolymp.apollo.Submission.Run.cpu_time_usage', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_usage', full_name='eolymp.apollo.Submission.Run.memory_usage', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_index', full_name='eolymp.apollo.Submission.Run.test_index', index=4,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_id', full_name='eolymp.apollo.Submission.Run.test_id', index=5,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.apollo.Submission.Run.status', index=6,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SUBMISSION_RUN_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=721,
)

_SUBMISSION = _descriptor.Descriptor(
  name='Submission',
  full_name='eolymp.apollo.Submission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.apollo.Submission.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.Submission.problem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.apollo.Submission.user_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submitted_at', full_name='eolymp.apollo.Submission.submitted_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.apollo.Submission.lang', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.apollo.Submission.source', index=5,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.apollo.Submission.status', index=6,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='eolymp.apollo.Submission.error', index=7,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.apollo.Submission.score', index=8,
      number=30, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runs', full_name='eolymp.apollo.Submission.runs', index=9,
      number=50, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SUBMISSION_RUN, ],
  enum_types=[
    _SUBMISSION_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=818,
)

_SUBMISSION_RUN.fields_by_name['status'].enum_type = _SUBMISSION_RUN_STATUS
_SUBMISSION_RUN.containing_type = _SUBMISSION
_SUBMISSION_RUN_STATUS.containing_type = _SUBMISSION_RUN
_SUBMISSION.fields_by_name['submitted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SUBMISSION.fields_by_name['status'].enum_type = _SUBMISSION_STATUS
_SUBMISSION.fields_by_name['runs'].message_type = _SUBMISSION_RUN
_SUBMISSION_STATUS.containing_type = _SUBMISSION
DESCRIPTOR.message_types_by_name['Submission'] = _SUBMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Submission = _reflection.GeneratedProtocolMessageType('Submission', (_message.Message,), {

  'Run' : _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
    'DESCRIPTOR' : _SUBMISSION_RUN,
    '__module__' : 'eolymp.apollo.submission_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.apollo.Submission.Run)
    })
  ,
  'DESCRIPTOR' : _SUBMISSION,
  '__module__' : 'eolymp.apollo.submission_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.Submission)
  })
_sym_db.RegisterMessage(Submission)
_sym_db.RegisterMessage(Submission.Run)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/status.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/status.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x65olymp/executor/status.proto\x12\x0f\x65olymp.executor\"\xef\x05\n\x06Status\x12\x11\n\treference\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12*\n\x04type\x18\n \x01(\x0e\x32\x1c.eolymp.executor.Status.Type\x12\r\n\x05\x65rror\x18\x14 \x01(\t\x12\x0f\n\x07\x66\x61ilure\x18\x1e \x01(\t\x12)\n\x04runs\x18( \x03(\x0b\x32\x1b.eolymp.executor.Status.Run\x12\x11\n\tsignature\x18\x32 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\x05\x12\r\n\x05\x61gent\x18n \x01(\t\x1a\xe1\x03\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12\x32\n\x06status\x18\x02 \x01(\x0e\x32\".eolymp.executor.Status.Run.Status\x12\r\n\x05score\x18\x03 \x01(\x02\x12\x17\n\x0fwall_time_usage\x18\x04 \x01(\x05\x12\x16\n\x0e\x63pu_time_usage\x18\x05 \x01(\x05\x12\x14\n\x0cmemory_usage\x18\x06 \x01(\x05\x12\x11\n\texit_code\x18\x07 \x01(\x05\x12\x0e\n\x06signal\x18\x08 \x01(\x05\x12\x0e\n\x06output\x18\n \x01(\t\x12\x0e\n\x06stderr\x18\x14 \x01(\t\x12\x14\n\x0cverifier_log\x18\x1e \x01(\t\x12\x16\n\x0einteractor_log\x18( \x01(\t\"\xcb\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x11\n\rRUNTIME_ERROR\x10\x06\x12\x0c\n\x08\x45XECUTED\x10\x07\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x08\x12\x10\n\x0cWRONG_ANSWER\x10\t\x12\x18\n\x14VERIFICATION_FAILURE\x10\n\x12\x0b\n\x07SKIPPED\x10\x0b\"4\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
)



_STATUS_RUN_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.executor.Status.Run.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXECUTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPU_EXHAUSTED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEMORY_OVERFLOW', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNTIME_ERROR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXECUTED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WRONG_ANSWER', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERIFICATION_FAILURE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=544,
  serialized_end=747,
)
_sym_db.RegisterEnumDescriptor(_STATUS_RUN_STATUS)

_STATUS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.executor.Status.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=749,
  serialized_end=801,
)
_sym_db.RegisterEnumDescriptor(_STATUS_TYPE)


_STATUS_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='eolymp.executor.Status.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='eolymp.executor.Status.Run.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.executor.Status.Run.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.executor.Status.Run.score', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wall_time_usage', full_name='eolymp.executor.Status.Run.wall_time_usage', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_time_usage', full_name='eolymp.executor.Status.Run.cpu_time_usage', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_usage', full_name='eolymp.executor.Status.Run.memory_usage', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='eolymp.executor.Status.Run.exit_code', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='eolymp.executor.Status.Run.signal', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='eolymp.executor.Status.Run.output', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stderr', full_name='eolymp.executor.Status.Run.stderr', index=9,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verifier_log', full_name='eolymp.executor.Status.Run.verifier_log', index=10,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactor_log', full_name='eolymp.executor.Status.Run.interactor_log', index=11,
      number=40, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATUS_RUN_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=747,
)

_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='eolymp.executor.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='eolymp.executor.Status.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin', full_name='eolymp.executor.Status.origin', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.executor.Status.type', index=2,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='eolymp.executor.Status.error', index=3,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure', full_name='eolymp.executor.Status.failure', index=4,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runs', full_name='eolymp.executor.Status.runs', index=5,
      number=40, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='eolymp.executor.Status.signature', index=6,
      number=50, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='eolymp.executor.Status.version', index=7,
      number=100, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent', full_name='eolymp.executor.Status.agent', index=8,
      number=110, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATUS_RUN, ],
  enum_types=[
    _STATUS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=801,
)

_STATUS_RUN.fields_by_name['status'].enum_type = _STATUS_RUN_STATUS
_STATUS_RUN.containing_type = _STATUS
_STATUS_RUN_STATUS.containing_type = _STATUS_RUN
_STATUS.fields_by_name['type'].enum_type = _STATUS_TYPE
_STATUS.fields_by_name['runs'].message_type = _STATUS_RUN
_STATUS_TYPE.containing_type = _STATUS
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {

  'Run' : _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
    'DESCRIPTOR' : _STATUS_RUN,
    '__module__' : 'eolymp.executor.status_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.Status.Run)
    })
  ,
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'eolymp.executor.status_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.Status)
  })
_sym_db.RegisterMessage(Status)
_sym_db.RegisterMessage(Status.Run)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
